/*******************************************************************************
*                                                                              *
*  Apk-file installation dialog implementation.                                *
*                                                                              *
*  Copyright (C) 2012 Kirill Chuvilin.                                         *
*  All rights reserved.                                                        *
*  Contact: Kirill Chuvilin (kirill.chuvilin@gmail.com, kirill.chuvilin.pro)   *
*                                                                              *
*  This file is part of the apkenv-qml project.                                *
*                                                                              *
*  $QT_BEGIN_LICENSE:GPL$                                                      *
*  You may use this file under the terms of the GNU General Public License     *
*  as published by the Free Software Foundation; version 3 of the License.     *
*                                                                              *
*  This file is distributed in the hope that it will be useful,                *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                *
*  GNU General Public License for more details.                                *
*                                                                              *
*  You should have received a copy of the GNU General Public License           *
*  along with this package; if not, write to the Free Software                 *
*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.   *
*  $QT_END_LICENSE$                                                            *
*                                                                              *
*******************************************************************************/

import Qt 4.7
import "QKit"
import ApkFile 1.0

QKitDialog {
    id: addApkFileDialog
    objectName: "AddApkFileDialog"

    property ApkFile apkFile: ApkFile {}

    signal installToggled() // emits when install button clicked

    QKitDialogText {
        id: infoText

        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.topMargin: 0.5 * font.pixelSize
        text: qsTr("Select .apk, icon files and name, than click on \"Install\".")
        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: 0.04 * Math.min(parent.width, parent.height)
    }

    QKitNavListView { // menu view
        id: view

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: infoText.bottom
        anchors.topMargin: (addApkFileDialog.height - infoText.height - cText.height - height) / 2
        width: 0.9 * Math.min(parent.width, parent.height)
        height: 0.6 * width
        spacing: 0.025 * width
        keyNavigationWraps: true

        model: VisualItemModel {
            SelectFileDialogElement {
                id: apkElement
                controllerSource: view
                width: view.width
                label: qsTr("APK")
                path: addApkFileDialog.apkFile.path
                onButtonClicked: {
                    selectFilePage.action = "apk"
                    selectFilePage.mediaDir.nameFilters = ["*.apk"];
                    selectFilePage.open()
                }
            }
//            QKitTextInput {
//                controllerSource: view
//                width: view.width
//                height: apkElement.height
//                text: addApkFileDialog.apkFile.name
//                onTextChanged: addApkFileDialog.apkFile.name = text
//           }
            SelectFileDialogElement {
                controllerSource: view
                width: view.width
                label: qsTr("Icon")
                path: addApkFileDialog.apkFile.iconPath
                onButtonClicked: {
                    selectFilePage.action = "icon"
                    selectFilePage.mediaDir.nameFilters = ["*.png", "*.jpg", "*.gif", "*.bmp", "*.svg"];
                    selectFilePage.open()
                }
            }
            QKitDialogText {
                controllerSource: view
                width: view.width
                height: 0.1 * width
                font.pixelSize: 0.5 * height
                text: addApkFileDialog.apkFile.name
                horizontalAlignment: Text.AlignHCenter
                elide: Text.ElideLeft
            }
            QKitItem {
                controllerSource: view
                width: view.width
                height: 0.1 * width
                QKitDialogButton {
                    anchors.left: parent.left
                    anchors.leftMargin: 0.25 * view.width
                    anchors.right: parent.right
                    anchors.rightMargin: 0.25 * view.width
                    height: parent.height
                    text: qsTr("Install")
                    onClicked: addApkFileDialog.installToggled()
                }
            }
        }
    }

    CText {id: cText}

    SelectFilePage {
        id: selectFilePage
        objectName: "SelectDialog"

        property string action: ""

        visible: false

        onVisibleChanged: if (!visible) addApkFileDialog.forceActiveFocus()
        onSelectedFilePathChanged: {
            if (selectedFilePath != "") {
                if (action == "apk") {
                    addApkFileDialog.apkFile.path = selectedFilePath
                } else if (action == "icon") {
                    addApkFileDialog.apkFile.iconPath = selectedFilePath
                }
            }
        }
    }
}
