/*******************************************************************************
*                                                                              *
*  Page with installed apk-files implementation.                               *
*                                                                              *
*  Copyright (C) 2012 Kirill Chuvilin.                                         *
*  All rights reserved.                                                        *
*  Contact: Kirill Chuvilin (kirill.chuvilin@gmail.com, kirill.chuvilin.pro)   *
*                                                                              *
*  This file is part of the apkenv-qml project.                                *
*                                                                              *
*  $QT_BEGIN_LICENSE:GPL$                                                      *
*  You may use this file under the terms of the GNU General Public License     *
*  as published by the Free Software Foundation; version 3 of the License.     *
*                                                                              *
*  This file is distributed in the hope that it will be useful,                *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                *
*  GNU General Public License for more details.                                *
*                                                                              *
*  You should have received a copy of the GNU General Public License           *
*  along with this package; if not, write to the Free Software                 *
*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.   *
*  $QT_END_LICENSE$                                                            *
*                                                                              *
*******************************************************************************/

import Qt 4.7
import "QKit"
import ApkRecord 1.0

QKitPage {
    id: homePage

    property alias apkFiles: apkFilesView.model
    signal addApkFileToggled() // emits when add button clicked
    signal removeApkFileToggled(int apkFileId) // emits when need to remove apk-file

    toolbar: QKitToolbar {
        QKitToolbarAddButton { onClicked: homePage.addApkFileToggled() }
        QKitToolbarMenuButton { onClicked: homePage.menuToggled() }
    }

    QKitNavGridView {
        id: apkFilesView

        anchors.top: parent.top
        anchors.bottom: mwText.top
        anchors.left: parent.left
        anchors.right: parent.right
        cellWidth: Math.min(1.0 / Math.round(width / 120), 0.5) * width - 0.5
        cellHeight: 1.1 * cellWidth
        keyNavigationWraps: false

        delegate: QKitItem {
            property ApkRecord apkFile: apkFilesView.model[index]

            width: apkFilesView.cellWidth
            height: apkFilesView.cellHeight
            controllerSource: apkFilesView
            Item {
                anchors.fill: parent
                anchors.bottomMargin: 0.2 * parent.height
                Image {
                    anchors.centerIn: parent
                    source: apkFile.iconSource
                }
            }
            Text {
                anchors.fill: parent
                anchors.topMargin: 0.75 * parent.height
                anchors.leftMargin: 0.05 * parent.width
                anchors.rightMargin: 0.05 * parent.width
                text: apkFile.name + "\n" + apkFile.version
                font.pixelSize: 0.5 * height
                horizontalAlignment: Text.AlignHCenter
                elide: Text.ElideRight
            }
            Keys.onPressed: apkFile.exec()
            MouseArea {
                anchors.fill: parent
                onClicked: apkFile.exec()
                onPressAndHold: homePage.removeApkFileToggled(apkFile.id)
            }
        }
    }

    QKitText {
        id: mwText
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        textFormat: Text.RichText
        horizontalAlignment: Text.AlignHCenter
        text: (application.isForStore ? qsTr("Please visit MaemoWorld.ru forum for details.") : qsTr("Please visit <a href=\"" + application.externalUrl('homepage') + "\" style=\"color:#FF0000\">MaemoWorld.ru forum</a> for details."))
        onLinkActivated: Qt.openUrlExternally(link)
        font.pixelSize: 0.035 * Math.min(parent.width, parent.height)
        wrapMode: Text.WordWrap
    }
}
