/*******************************************************************************
*                                                                              *
*  Main application item implementation.                                       *
*                                                                              *
*  Copyright (C) 2012 Kirill Chuvilin.                                         *
*  All rights reserved.                                                        *
*  Contact: Kirill Chuvilin (kirill.chuvilin@gmail.com, kirill.chuvilin.pro)   *
*                                                                              *
*  This file is part of the apkenv-qml project.                                *
*                                                                              *
*  $QT_BEGIN_LICENSE:GPL$                                                      *
*  You may use this file under the terms of the GNU General Public License     *
*  as published by the Free Software Foundation; version 3 of the License.     *
*                                                                              *
*  This file is distributed in the hope that it will be useful,                *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                *
*  GNU General Public License for more details.                                *
*                                                                              *
*  You should have received a copy of the GNU General Public License           *
*  along with this package; if not, write to the Free Software                 *
*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.   *
*  $QT_END_LICENSE$                                                            *
*                                                                              *
*******************************************************************************/

import Qt 4.7
import "QKit"
import ApkDb 1.0
import Apkenv 1.0
import AppSettings 1.0

QKitApplication {
    id: application

    property AppSettings appSettings: AppSettings {}
    property ApkDb apkDb: ApkDb {}
    property Apkenv apkenv: Apkenv {
        executePath: appSettings.apkenvPath;
    }

    property bool isForStore: false

    function externalUrl(link) {
        return "http://scripts.chuvilin.pro/appredirect.php?app=" + appSettings.appName + "&link=" + link +"&platform=" + os + "&version=" + appSettings.version + (isForStore ? "&isforstore=true" : "");
    }

    logController: LogController { }

    HomePage {
        id: homePage
        objectName: "HomePage"
        apkFiles: apkDb.apkFiles
        onMenuToggled: menu.active = true
        onAddApkFileToggled: addApkFileDialog.active = true
        onRemoveApkFileToggled: apkDb.removeApk(apkFileId)
    }

    Menu {
        id: menu
        onClosed: homePage.forceActiveFocus()
        onSettingsToggled: settingsDialog.active = true;
    }

    AddApkFileDialog {
        id: addApkFileDialog
        onClosed: homePage.forceActiveFocus()
        onInstallToggled: {
            if (apkDb.addApk(addApkFileDialog.apkFile.path, addApkFileDialog.apkFile.name, addApkFileDialog.apkFile.iconPath)) active = false;
        }
    }

    SettingsDialog {
        id: settingsDialog
        appSettings: application.appSettings;
        onClosed: homePage.forceActiveFocus()
    }

    // todo: why does focus goes to menuview?
    Component.onCompleted: forceActiveFocus()
}
