/*******************************************************************************
*                                                                              *
*  Settings dialog implementation.                                             *
*                                                                              *
*  Copyright (C) 2012 Kirill Chuvilin.                                         *
*  All rights reserved.                                                        *
*  Contact: Kirill Chuvilin (kirill.chuvilin@gmail.com, kirill.chuvilin.pro)   *
*                                                                              *
*  This file is part of the apkenv-qml project.                                *
*                                                                              *
*  $QT_BEGIN_LICENSE:GPL$                                                      *
*  You may use this file under the terms of the GNU General Public License     *
*  as published by the Free Software Foundation; version 3 of the License.     *
*                                                                              *
*  This file is distributed in the hope that it will be useful,                *
*  but WITHOUT ANY WARRANTY; without even the implied warranty of              *
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                *
*  GNU General Public License for more details.                                *
*                                                                              *
*  You should have received a copy of the GNU General Public License           *
*  along with this package; if not, write to the Free Software                 *
*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.   *
*  $QT_END_LICENSE$                                                            *
*                                                                              *
*******************************************************************************/

import Qt 4.7
import "QKit"
import AppSettings 1.0

QKitDialog {
    id: settingsDialog
    objectName: "settingsDialog"

    property AppSettings appSettings; // Settings object
    property bool doSaveChanges: false;

    onVisibleChanged: {
        if (settingsDialog.visible) {
            settingsDialog.doSaveChanges = false;
        } else {
            if (!appSettings) return;
            if (settingsDialog.doSaveChanges) {
                settingsDialog.appSettings.backupValues();
            } else {
                settingsDialog.appSettings.restoreValues();
            }
        }
    }

    QKitNavListView { // menu view
        id: view

        property int bodyHeight: Math.min(settingsDialog.height - cText.height, childrenRect.height)

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: (settingsDialog.height - cText.height - bodyHeight) / 2
        anchors.bottom: cText.top
        anchors.bottomMargin: (settingsDialog.height - cText.height - bodyHeight) / 2
        width: 0.9 * Math.min(parent.width, parent.height)
        spacing: 0.03 * width
        keyNavigationWraps: true
        model: VisualItemModel {
            SelectFileDialogElement {
                controllerSource: settingsDialog
                width: view.width
                label: qsTr("apkenv")
                path: appSettings.apkenvPath
                onButtonClicked: {
                    selectFilePage.action = "apkenv"
                    selectFilePage.mediaDir.nameFilters = ["*"];
                    selectFilePage.open()
                }
            }
            QKitItem {
                controllerSource: settingsDialog
                width: view.width
                height: 0.1 * view.width
                QKitDialogButton {
                    anchors.left: parent.left
                    width: 0.45 * parent.width
                    height: 0.1 * parent.width
                    text: qsTr("Save")
                    onClicked: {
                        settingsDialog.doSaveChanges = true;
                        settingsDialog.active = false;
                    }
                }
                QKitDialogButton {
                    anchors.right: parent.right
                    width: 0.45 * parent.width
                    height: 0.1 * parent.width
                    text: qsTr("Reset")
                    onClicked: settingsDialog.appSettings.reset()
                }
            }
        }
    }

    CText {id: cText}

    SelectFilePage {
        id: selectFilePage
        objectName: "selectFilePage"

        property string action: ""

        visible: false

        onVisibleChanged: if (!visible) settingsDialog.forceActiveFocus()
        onSelectedFilePathChanged: {
            if (selectedFilePath != "") {
                if (action == "apkenv") {
                    settingsDialog.appSettings.apkenvPath = selectedFilePath
                }
            }
        }
    }
}
